<?php
/**
 * Medicos Lite functions and definitions
 *
 * @package Medicos Lite
 */

if ( ! function_exists( 'medicos_lite_setup' ) ) :
/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which runs
 * before the init hook. The init hook is too late for some features, such as indicating
 * support post thumbnails.
 */
function medicos_lite_setup() {
	
	if ( ! isset( $content_width ) )
		$content_width = 640; /* pixels */

	load_theme_textdomain( 'medicos-lite', get_template_directory() . '/languages' );
	add_theme_support( 'automatic-feed-links' );
	add_theme_support( 'post-thumbnails' );
	add_theme_support( 'title-tag' );
	add_theme_support( 'custom-logo', array(
		'height'      => 240,
		'width'       => 240,
		'flex-height' => true,
	) );
	add_image_size('medicos-lite-feature-thumb',500,400,true);
	register_nav_menus( array(
		'primary' => __( 'Primary Menu', 'medicos-lite' ),		
	) );
	add_theme_support( 'custom-background', array(
		'default-color' => 'f1f1f1'
	) );
	
	// Add support for Block Styles.
	add_theme_support( 'wp-block-styles' );

	// Add support for full and wide align images.
	add_theme_support( 'align-wide' );
	
	add_filter('use_widgets_block_editor', '__return_false');
	
	/*
		 * Switch default core markup for search form, comment form, and comments
		 * to output valid HTML5.
		 */
		add_theme_support(
			'html5',
			array(
				'comment-form',
				'comment-list',
				'gallery',
				'caption',
				'style',
				'script',
				'navigation-widgets',
			)
		);
	
	// Add support for responsive embedded content.
	add_theme_support( 'responsive-embeds' );
	add_editor_style( array( 'editor-style.css', medicos_lite_font_url() ) );
}
endif; // medicos_lite_setup
add_action( 'after_setup_theme', 'medicos_lite_setup' );


function medicos_lite_widgets_init() {
	register_sidebar( array(
		'name'          => __( 'Blog Sidebar', 'medicos-lite' ),
		'description'   => __( 'Appears on blog page sidebar', 'medicos-lite' ),
		'id'            => 'sidebar-1',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );

}
add_action( 'widgets_init', 'medicos_lite_widgets_init' );

function medicos_lite_font_url(){
		$font_url = '';
		
		/* Translators: If there are any character that are
		* not supported by Karla, translate this to off, do not
		* translate into your own language.
		*/
		$karla = _x('on', 'Karla font:on or off','medicos-lite');
		
		/* Translators: If there are any character that are
		* not supported by Roboto, translate this to off, do not
		* translate into your own language.
		*/
		$robot = _x('on', 'Roboto font:on or off','medicos-lite');
		
		/* Translators: If there are any character that are
		* not supported by Rajdhani, translate this to off, do not
		* translate into your own language.
		*/
		$rajdha = _x('on', 'Rajdhani font:on or off','medicos-lite');
		
		if('off' !== $karla || 'off' !== $robot || 'off' !== $rajdha ){
			$font_family = array();
			
			if('off' !== $karla){
				$font_family[] = 'Karla:400,700';
			}
			if('off' !== $robot){
				$font_family[] = 'Roboto:400,700';
			}
			if('off' !== $rajdha){
				$font_family[] = 'Rajdhani:400,700,900';
			}
			$query_args = array(
				'family'	=> urlencode(implode('|',$font_family)),
			);
			
			$font_url = add_query_arg($query_args,'https://fonts.googleapis.com/css');
		}
		
	return $font_url;
	}

function medicos_lite_scripts() {
	wp_enqueue_style( 'medicos-lite-font', medicos_lite_font_url(), array() );
	wp_enqueue_style( 'medicos-lite-basic-style', get_stylesheet_uri() );
	wp_enqueue_style( 'medicos-lite-responsive-style', get_template_directory_uri().'/css/theme-responsive.css' );
	wp_enqueue_style( 'nivo-style', get_template_directory_uri().'/css/nivo-slider.css');
	wp_enqueue_style( 'font-awesome-style', get_template_directory_uri().'/css/font-awesome.css' );	
	wp_enqueue_script( 'medicos-lite-navigation', get_template_directory_uri() . '/js/navigation.js', array('jquery'), '20190715', true );
	wp_enqueue_script( 'jquery-nivo-slider-js', get_template_directory_uri() . '/js/jquery.nivo.slider.js', array('jquery') );
	wp_enqueue_script( 'medicos-lite-customscripts', get_template_directory_uri() . '/js/custom.js', array('jquery') );
	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
	wp_localize_script( 'medicos-lite-navigation', 'MedicosliteScreenReaderText', array() );
}
add_action( 'wp_enqueue_scripts', 'medicos_lite_scripts' );

/**
 * Use front-page.php when Front page displays is set to a static page.
 *
 *
 * @param string $template front-page.php.
 *
 * @return string The template to be used: blank if is_home() is true (defaults to index.php), else $template.
 */
function medicos_lite_front_page_template( $template ) {
	return is_home() ? '' : $template;
}
add_filter( 'frontpage_template',  'medicos_lite_front_page_template' );

/**
 * Implement the Custom Header feature.
 */
require get_template_directory() . '/inc/custom-header.php';

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Custom functions that act independently of the theme templates.
 */
require get_template_directory() . '/inc/extras.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/customizer.php';

/*
 * Load customize pro
 */
require_once( trailingslashit( get_template_directory() ) . 'customize-pro/class-customize.php' );

/*
 * Slider Function
 */
if ( ! function_exists ( 'medicos_theme_slider' ) ) {
	function medicos_theme_slider(){
		if( is_home() || is_front_page() ){
			$medi_hideslider = get_theme_mod('medi_hide_slider', '1');
			if($medi_hideslider == ''){
				$medicos_lite_pages = array();
				for($sld=1; $sld<4; $sld++) { 
					$mod = absint( get_theme_mod('slider'.$sld));
					if ( 'page-none-selected' != $mod ) {
						$medicos_lite_pages[] = $mod;
					} 
				}
				if( !empty($medicos_lite_pages) ) :
					$args = array(
					  'posts_per_page' => 3,
					  'post_type' => 'page',
					  'post__in' => $medicos_lite_pages,
					  'orderby' => 'post__in'
					);
					$sldr_query = new WP_Query( $args );
					if ( $sldr_query->have_posts() ) : 
						$sld = 7;
						echo '<section id="theme_slider"><div class="slider-wrapper theme-default"><div id="slider" class="nivoSlider">';
						$i = 0;
						while ( $sldr_query->have_posts() ) : $sldr_query->the_post();
							$i++;
							$medicos_lite_slideno[] = $i;
							$medicos_lite_slidetitle[] = get_the_title();
							$medicos_lite_slidedesc[] = get_the_excerpt();
							$medicos_lite_slidelink[] = esc_url(get_permalink());

							$imgSrc = wp_get_attachment_image_src( get_post_thumbnail_id(), 'full');

							if ( $imgSrc[0]!='' ) {
								$imgUrl = $imgSrc[0];
							}

							echo '<img src="'.$imgSrc[0].'" title="#slidecaption'.esc_attr( $i ).'" />';

							$sld++;
						endwhile;
						echo '</div>';
						$k = 0;
						foreach( $medicos_lite_slideno as $medicos_lite_sln ){
							echo '<div id="slidecaption'.esc_attr( $medicos_lite_sln ).'" class="nivo-html-caption">
								<h2><a href="'.esc_url($medicos_lite_slidelink[$k] ).'">'.esc_html($medicos_lite_slidetitle[$k] ).'</a></h2>
								<p>'.esc_html($medicos_lite_slidedesc[$k] ).'</p>
								<a class="slide-button" href="'.esc_url($medicos_lite_slidelink[$k] ).'">
									'.esc_html(get_theme_mod('medi_slide_more',__('Read More','medicos-lite'))).'
								</a>
							</div>';
							$k++;
							wp_reset_postdata();
						}
					endif;
				endif;
				echo '</div></section>';
			}
		}
	}
}